import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SignonPolicyRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Allow or deny access based on the rule conditions: ALLOW, DENY or CHALLENGE.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#access SignonPolicyRule#access}
    */
    readonly access?: string;
    /**
    * Authentication entrypoint: ANY, RADIUS or LDAP_INTERFACE
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#authtype SignonPolicyRule#authtype}
    */
    readonly authtype?: string;
    /**
    * List of behavior IDs
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#behaviors SignonPolicyRule#behaviors}
    */
    readonly behaviors?: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#id SignonPolicyRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Apply rule based on the IdP used: ANY, OKTA or SPECIFIC_IDP.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#identity_provider SignonPolicyRule#identity_provider}
    */
    readonly identityProvider?: string;
    /**
    * When identity_provider is SPECIFIC_IDP then this is the list of IdP IDs to apply the rule on
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#identity_provider_ids SignonPolicyRule#identity_provider_ids}
    */
    readonly identityProviderIds?: string[];
    /**
    * Elapsed time before the next MFA challenge
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#mfa_lifetime SignonPolicyRule#mfa_lifetime}
    */
    readonly mfaLifetime?: number;
    /**
    * Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: DEVICE, SESSION or ALWAYS
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#mfa_prompt SignonPolicyRule#mfa_prompt}
    */
    readonly mfaPrompt?: string;
    /**
    * Remember MFA device.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#mfa_remember_device SignonPolicyRule#mfa_remember_device}
    */
    readonly mfaRememberDevice?: boolean | cdktf.IResolvable;
    /**
    * Require MFA.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#mfa_required SignonPolicyRule#mfa_required}
    */
    readonly mfaRequired?: boolean | cdktf.IResolvable;
    /**
    * Policy Rule Name
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#name SignonPolicyRule#name}
    */
    readonly name: string;
    /**
    * Network selection mode: ANYWHERE, ZONE, ON_NETWORK, or OFF_NETWORK.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#network_connection SignonPolicyRule#network_connection}
    */
    readonly networkConnection?: string;
    /**
    * The zones to exclude
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#network_excludes SignonPolicyRule#network_excludes}
    */
    readonly networkExcludes?: string[];
    /**
    * The zones to include
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#network_includes SignonPolicyRule#network_includes}
    */
    readonly networkIncludes?: string[];
    /**
    * Policy ID of the Rule
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#policy_id SignonPolicyRule#policy_id}
    */
    readonly policyId?: string;
    /**
    * Policy ID of the Rule
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#policyid SignonPolicyRule#policyid}
    */
    readonly policyid?: string;
    /**
    * Primary factor.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#primary_factor SignonPolicyRule#primary_factor}
    */
    readonly primaryFactor?: string;
    /**
    * Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an invalid priority is provided. API defaults it to the last (lowest) if not there.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#priority SignonPolicyRule#priority}
    */
    readonly priority?: number;
    /**
    * Risc level: ANY, LOW, MEDIUM or HIGH
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#risc_level SignonPolicyRule#risc_level}
    */
    readonly riscLevel?: string;
    /**
    * Max minutes a session can be idle.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#session_idle SignonPolicyRule#session_idle}
    */
    readonly sessionIdle?: number;
    /**
    * Max minutes a session is active: Disable = 0.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#session_lifetime SignonPolicyRule#session_lifetime}
    */
    readonly sessionLifetime?: number;
    /**
    * Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#session_persistent SignonPolicyRule#session_persistent}
    */
    readonly sessionPersistent?: boolean | cdktf.IResolvable;
    /**
    * Policy Rule Status: ACTIVE or INACTIVE.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#status SignonPolicyRule#status}
    */
    readonly status?: string;
    /**
    * Set of User IDs to Exclude
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#users_excluded SignonPolicyRule#users_excluded}
    */
    readonly usersExcluded?: string[];
    /**
    * factor_sequence block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#factor_sequence SignonPolicyRule#factor_sequence}
    */
    readonly factorSequence?: SignonPolicyRuleFactorSequence[] | cdktf.IResolvable;
}
export interface SignonPolicyRuleFactorSequenceSecondaryCriteria {
    /**
    * Type of a Factor
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#factor_type SignonPolicyRule#factor_type}
    */
    readonly factorType: string;
    /**
    * Factor provider
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#provider SignonPolicyRule#provider}
    */
    readonly provider: string;
}
export declare function signonPolicyRuleFactorSequenceSecondaryCriteriaToTerraform(struct?: SignonPolicyRuleFactorSequenceSecondaryCriteria | cdktf.IResolvable): any;
export declare class SignonPolicyRuleFactorSequenceSecondaryCriteriaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SignonPolicyRuleFactorSequenceSecondaryCriteria | cdktf.IResolvable | undefined;
    set internalValue(value: SignonPolicyRuleFactorSequenceSecondaryCriteria | cdktf.IResolvable | undefined);
    private _factorType?;
    get factorType(): string;
    set factorType(value: string);
    get factorTypeInput(): string | undefined;
    private _provider?;
    get provider(): string;
    set provider(value: string);
    get providerInput(): string | undefined;
}
export declare class SignonPolicyRuleFactorSequenceSecondaryCriteriaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SignonPolicyRuleFactorSequenceSecondaryCriteria[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SignonPolicyRuleFactorSequenceSecondaryCriteriaOutputReference;
}
export interface SignonPolicyRuleFactorSequence {
    /**
    * Type of a Factor
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#primary_criteria_factor_type SignonPolicyRule#primary_criteria_factor_type}
    */
    readonly primaryCriteriaFactorType: string;
    /**
    * Factor provider
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#primary_criteria_provider SignonPolicyRule#primary_criteria_provider}
    */
    readonly primaryCriteriaProvider: string;
    /**
    * secondary_criteria block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule#secondary_criteria SignonPolicyRule#secondary_criteria}
    */
    readonly secondaryCriteria?: SignonPolicyRuleFactorSequenceSecondaryCriteria[] | cdktf.IResolvable;
}
export declare function signonPolicyRuleFactorSequenceToTerraform(struct?: SignonPolicyRuleFactorSequence | cdktf.IResolvable): any;
export declare class SignonPolicyRuleFactorSequenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SignonPolicyRuleFactorSequence | cdktf.IResolvable | undefined;
    set internalValue(value: SignonPolicyRuleFactorSequence | cdktf.IResolvable | undefined);
    private _primaryCriteriaFactorType?;
    get primaryCriteriaFactorType(): string;
    set primaryCriteriaFactorType(value: string);
    get primaryCriteriaFactorTypeInput(): string | undefined;
    private _primaryCriteriaProvider?;
    get primaryCriteriaProvider(): string;
    set primaryCriteriaProvider(value: string);
    get primaryCriteriaProviderInput(): string | undefined;
    private _secondaryCriteria;
    get secondaryCriteria(): SignonPolicyRuleFactorSequenceSecondaryCriteriaList;
    putSecondaryCriteria(value: SignonPolicyRuleFactorSequenceSecondaryCriteria[] | cdktf.IResolvable): void;
    resetSecondaryCriteria(): void;
    get secondaryCriteriaInput(): cdktf.IResolvable | SignonPolicyRuleFactorSequenceSecondaryCriteria[] | undefined;
}
export declare class SignonPolicyRuleFactorSequenceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SignonPolicyRuleFactorSequence[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SignonPolicyRuleFactorSequenceOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule okta_signon_policy_rule}
*/
export declare class SignonPolicyRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "okta_signon_policy_rule";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/okta/r/signon_policy_rule okta_signon_policy_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SignonPolicyRuleConfig
    */
    constructor(scope: Construct, id: string, config: SignonPolicyRuleConfig);
    private _access?;
    get access(): string;
    set access(value: string);
    resetAccess(): void;
    get accessInput(): string | undefined;
    private _authtype?;
    get authtype(): string;
    set authtype(value: string);
    resetAuthtype(): void;
    get authtypeInput(): string | undefined;
    private _behaviors?;
    get behaviors(): string[];
    set behaviors(value: string[]);
    resetBehaviors(): void;
    get behaviorsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _identityProvider?;
    get identityProvider(): string;
    set identityProvider(value: string);
    resetIdentityProvider(): void;
    get identityProviderInput(): string | undefined;
    private _identityProviderIds?;
    get identityProviderIds(): string[];
    set identityProviderIds(value: string[]);
    resetIdentityProviderIds(): void;
    get identityProviderIdsInput(): string[] | undefined;
    private _mfaLifetime?;
    get mfaLifetime(): number;
    set mfaLifetime(value: number);
    resetMfaLifetime(): void;
    get mfaLifetimeInput(): number | undefined;
    private _mfaPrompt?;
    get mfaPrompt(): string;
    set mfaPrompt(value: string);
    resetMfaPrompt(): void;
    get mfaPromptInput(): string | undefined;
    private _mfaRememberDevice?;
    get mfaRememberDevice(): boolean | cdktf.IResolvable;
    set mfaRememberDevice(value: boolean | cdktf.IResolvable);
    resetMfaRememberDevice(): void;
    get mfaRememberDeviceInput(): boolean | cdktf.IResolvable | undefined;
    private _mfaRequired?;
    get mfaRequired(): boolean | cdktf.IResolvable;
    set mfaRequired(value: boolean | cdktf.IResolvable);
    resetMfaRequired(): void;
    get mfaRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkConnection?;
    get networkConnection(): string;
    set networkConnection(value: string);
    resetNetworkConnection(): void;
    get networkConnectionInput(): string | undefined;
    private _networkExcludes?;
    get networkExcludes(): string[];
    set networkExcludes(value: string[]);
    resetNetworkExcludes(): void;
    get networkExcludesInput(): string[] | undefined;
    private _networkIncludes?;
    get networkIncludes(): string[];
    set networkIncludes(value: string[]);
    resetNetworkIncludes(): void;
    get networkIncludesInput(): string[] | undefined;
    private _policyId?;
    get policyId(): string;
    set policyId(value: string);
    resetPolicyId(): void;
    get policyIdInput(): string | undefined;
    private _policyid?;
    get policyid(): string;
    set policyid(value: string);
    resetPolicyid(): void;
    get policyidInput(): string | undefined;
    private _primaryFactor?;
    get primaryFactor(): string;
    set primaryFactor(value: string);
    resetPrimaryFactor(): void;
    get primaryFactorInput(): string | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    resetPriority(): void;
    get priorityInput(): number | undefined;
    private _riscLevel?;
    get riscLevel(): string;
    set riscLevel(value: string);
    resetRiscLevel(): void;
    get riscLevelInput(): string | undefined;
    private _sessionIdle?;
    get sessionIdle(): number;
    set sessionIdle(value: number);
    resetSessionIdle(): void;
    get sessionIdleInput(): number | undefined;
    private _sessionLifetime?;
    get sessionLifetime(): number;
    set sessionLifetime(value: number);
    resetSessionLifetime(): void;
    get sessionLifetimeInput(): number | undefined;
    private _sessionPersistent?;
    get sessionPersistent(): boolean | cdktf.IResolvable;
    set sessionPersistent(value: boolean | cdktf.IResolvable);
    resetSessionPersistent(): void;
    get sessionPersistentInput(): boolean | cdktf.IResolvable | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    private _usersExcluded?;
    get usersExcluded(): string[];
    set usersExcluded(value: string[]);
    resetUsersExcluded(): void;
    get usersExcludedInput(): string[] | undefined;
    private _factorSequence;
    get factorSequence(): SignonPolicyRuleFactorSequenceList;
    putFactorSequence(value: SignonPolicyRuleFactorSequence[] | cdktf.IResolvable): void;
    resetFactorSequence(): void;
    get factorSequenceInput(): cdktf.IResolvable | SignonPolicyRuleFactorSequence[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
